:mod:`eulfedora.models` - Fedora models
=======================================

.. module:: eulfedora.models


DigitalObject
-------------

.. autoclass:: DigitalObject
    :members:

Custom Exception
^^^^^^^^^^^^^^^^

.. autoclass:: DigitalObjectSaveFailure
    :members:

Datastream
----------

Datastream Descriptors
^^^^^^^^^^^^^^^^^^^^^^

.. autoclass:: Datastream
    :members:

.. autoclass:: XmlDatastream
    :members:

.. autoclass:: RdfDatastream
    :members:

.. autoclass:: FileDatastream
    :members:

Datastream Objects
^^^^^^^^^^^^^^^^^^

.. autoclass:: DatastreamObject
    :members:

.. autoclass:: XmlDatastreamObject
    :members:

.. autoclass:: RdfDatastreamObject
    :members:

.. autoclass:: FileDatastreamObject
    :members:

Relations
---------

.. autoclass:: Relation
   :members:

.. autoclass:: ReverseRelation
   :members:
